package com.android.test.p07listview;

import android.app.Activity;
import android.content.res.Configuration;
import android.graphics.drawable.Drawable;
import android.os.Bundle;
import android.view.KeyEvent;
import android.view.View;
import android.widget.ArrayAdapter;
import android.widget.EditText;
import android.widget.LinearLayout;
import android.widget.ListView;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

public class MainActivity extends Activity
{
    private   ArrayAdapter<String>  adapter     ;
    private   List<String>          names       ;
    private   LinearLayout          linearLayout;
    private   int                   orientation ;
    @Override
    protected void onCreate(Bundle savedInstanceState)
    {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_custom);

        linearLayout = findViewById(R.id.mainlayout);
        orientation  = Configuration.ORIENTATION_PORTRAIT;

        String[] data = getResources().getStringArray(R.array.names);
        names = new ArrayList<>(Arrays.asList(data));
//        for (int i = 0; i < data.length; i++)
//            names.add(data[i]);
//      names = Arrays.asList(getResources().getStringArray(R.array.names));
//      names = Arrays.asList();
/*
Он принимает массив ia и создает оболочку, которая реализует List<Integer>,
что делает исходный массив доступным как список. Ничего не скопировано и все,
создается только один объект-оболочка. Операции над оболочкой списка распространяются
на исходный массив. Это означает, что если вы перетасовываете оболочку списка,
исходный массив также перетасовывается, если вы перезаписываете элемент, он перезаписывается
в исходном массиве и т.д. Конечно, некоторые операции List не допускаются в оболочку,
например, добавление или удаление элементов из списка, вы можете только читать или
перезаписывать элементы.
 */
        adapter = new ArrayAdapter<>(this, R.layout.list_item, names);
        ListView listView = findViewById(R.id.list);

        listView.setAdapter(adapter);

        final EditText editText = findViewById(R.id.etItem);
        // Прослушиваем нажатия клавиш
        editText.setOnKeyListener(new View.OnKeyListener()
        {
            public boolean onKey(View v, int keyCode, KeyEvent event)
            {
                if (event.getAction() == KeyEvent.ACTION_DOWN)
                    if (keyCode == KeyEvent.KEYCODE_ENTER) {
                         names.add(editText.getText().toString());
                         adapter.notifyDataSetChanged();
                        editText.setText("");
                        return true;
                    }
                return false;
            }
        });
    }
    @Override
    public void onResume()
    {
        super.onResume();
        setBackgroundImage(orientation);
    }
    @Override
    public void onConfigurationChanged(Configuration newConfig)
    {
        super.onConfigurationChanged(newConfig);
        setBackgroundImage(newConfig.orientation);
        orientation = newConfig.orientation;
    }
    private void setBackgroundImage(final int orientation)
    {
        Drawable image = this.getResources().getDrawable(R.drawable.earth_landscape, null);
        if (orientation == Configuration.ORIENTATION_PORTRAIT)
            image = this.getResources().getDrawable(R.drawable.earth_portrait, null);
        image.setAlpha(32);
        linearLayout.setBackground(image);
    }
}
